#ifndef INC_IPTCfgParserTokenTypes_hpp_
#define INC_IPTCfgParserTokenTypes_hpp_

/* $ANTLR 2.7.6 (20070910): "iptables.g" -> "IPTCfgParserTokenTypes.hpp"$ */

#ifndef CUSTOM_API
# define CUSTOM_API
#endif

#ifdef __cplusplus
struct CUSTOM_API IPTCfgParserTokenTypes {
#endif
	enum {
		EOF_ = 1,
		NEWLINE = 4,
		LINE_COMMENT = 5,
		COMMIT = 6,
		STAR = 7,
		WORD = 8,
		INPUT = 9,
		FORWARD = 10,
		OUTPUT = 11,
		PREROUTING = 12,
		POSTROUTING = 13,
		COLON = 14,
		MINUS = 15,
		OPENING_SQUARE = 16,
		INT_CONST = 17,
		CLOSING_SQUARE = 18,
		ADD_RULE = 19,
		UNSUPPORTED_OPTION = 20,
		DIGIT = 21,
		SLASH = 22,
		OPT_MODULE = 23,
		OPT_SRC = 24,
		EXCLAMATION = 25,
		IPV4 = 26,
		OPT_DST = 27,
		OPT_IN_INTF = 28,
		OPT_OUT_INTF = 29,
		TCP = 30,
		UDP = 31,
		ICMP = 32,
		OPT_PROTO = 33,
		OPT_TARGET = 34,
		REJECT_WITH = 35,
		LOG_PREFIX = 36,
		STRING = 37,
		LOG_TCP_SEQ = 38,
		LOG_TCP_OPT = 39,
		LOG_IP_OPT = 40,
		ULOG_PREFIX = 41,
		LOG_LEVEL = 42,
		SET_MARK = 43,
		HEX_CONST = 44,
		SET_TOS = 45,
		SAVE_MARK = 46,
		RESTORE_MARK = 47,
		CONTINUE = 48,
		ROUTE_IIF = 49,
		ROUTE_OIF = 50,
		ROUTE_GW = 51,
		ROUTE_TEE = 52,
		TO_SOURCE = 53,
		TO_DESTINATION = 54,
		TO_PORTS = 55,
		TO_NETMAP = 56,
		CLAMP_MSS = 57,
		OPT_FRAGM = 58,
		INVALID = 59,
		NEW = 60,
		ESTABLISHED = 61,
		RELATED = 62,
		M_STATE = 63,
		MATCH_STATE = 64,
		COMMA = 65,
		M_MARK = 66,
		MATCH_MARK = 67,
		M_LIMIT = 68,
		MATCH_LIMIT = 69,
		MATCH_LIMIT_BURST = 70,
		M_MPORT = 71,
		M_COMMENT = 72,
		MATCH_COMMENT = 73,
		MATCH_SRC_MULTIPORT = 74,
		MATCH_SRC_MULTIPORT_SHORT = 75,
		MATCH_DST_MULTIPORT = 76,
		MATCH_DST_MULTIPORT_SHORT = 77,
		MATCH_ICMP_TYPE = 78,
		MATCH_SRC_PORT = 79,
		MATCH_SRC_PORT_SHORT = 80,
		MATCH_DST_PORT = 81,
		MATCH_DST_PORT_SHORT = 82,
		MATCH_SYN = 83,
		SYN = 84,
		ACK = 85,
		FIN = 86,
		RST = 87,
		URG = 88,
		PSH = 89,
		ALL = 90,
		NONE = 91,
		MATCH_TCP_FLAGS = 92,
		MATCH_TCP_OPTION = 93,
		Whitespace = 94,
		IPV6 = 95,
		MAC_ADDRESS = 96,
		NEG_INT_CONST = 97,
		HEXDIGIT = 98,
		NUM_3DIGIT = 99,
		NUM_HEX_4DIGIT = 100,
		NUMBER = 101,
		SECONDS = 102,
		SET = 103,
		RSOURCE = 104,
		ULOG_QTHR = 105,
		ULOG_NLG = 106,
		ULOG_CPR = 107,
		NUMBER_SIGN = 108,
		PERCENT = 109,
		AMPERSAND = 110,
		APOSTROPHE = 111,
		OPENING_PAREN = 112,
		CLOSING_PAREN = 113,
		PLUS = 114,
		DOT = 115,
		SEMICOLON = 116,
		LESS_THAN = 117,
		EQUALS = 118,
		GREATER_THAN = 119,
		QUESTION = 120,
		COMMERCIAL_AT = 121,
		CARET = 122,
		UNDERLINE = 123,
		OPENING_BRACE = 124,
		CLOSING_BRACE = 125,
		TILDE = 126,
		NULL_TREE_LOOKAHEAD = 3
	};
#ifdef __cplusplus
};
#endif
#endif /*INC_IPTCfgParserTokenTypes_hpp_*/
